@@ -2,7 +2,7 @@
 /* Mednafen - Multi-system Emulator                                           */
 /******************************************************************************/
 /* Stream.cpp:
-**  Copyright (C) 2012-2017 Mednafen Team
+**  Copyright (C) 2012-2018 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -45,6 +45,30 @@ void Stream::require_fast_seekable(void)
   throw MDFN_Error(0, _("Stream is not capable of fast seeks."));
 }
 
+static const uint8 utf8_bom[3] = { 0xEF, 0xBB, 0xBF };
+
+bool Stream::read_utf8_bom(void)
+{
+ uint8 bom_tmp[sizeof(utf8_bom)];
+ int read_count;
+
+ if((read_count = read(bom_tmp, sizeof(bom_tmp), false)) == sizeof(bom_tmp) && !memcmp(bom_tmp, utf8_bom, sizeof(bom_tmp)))
+ {
+  //::printf("BOM!\n");
+  return true;
+ }
+ else
+ {
+  seek(-read_count, SEEK_CUR);
+  return false;
+ }
+}
+
+void Stream::write_utf8_bom(void)
+{
+ write(utf8_bom, sizeof(utf8_bom));
+}
+
 uint64 Stream::read_discard(uint64 count)
 {
  uint8 buf[1024];
@@ -77,7 +101,7 @@ uint64 Stream::alloc_and_read(void** data_out, uint64 size_limit)
    data_buffer_alloced = 65536;
 
    if(!(data_buffer = (uint8*)realloc(data_buffer, data_buffer_alloced)))
-    throw MDFN_Error(ErrnoHolder(errno));
+    throw MDFN_Error(ErrnoHolder(ENOMEM));
 
    while((rti = read(data_buffer + data_buffer_size, data_buffer_alloced - data_buffer_size, false)) > 0)
    {
@@ -102,7 +126,7 @@ uint64 Stream::alloc_and_read(void** data_out, uint64 size_limit)
       throw MDFN_Error(ErrnoHolder(ENOMEM));
 
      if(!(new_data_buffer = (uint8 *)realloc(data_buffer, data_buffer_alloced)))
-      throw MDFN_Error(ErrnoHolder(errno));
+      throw MDFN_Error(ErrnoHolder(ENOMEM));
      data_buffer = new_data_buffer;
     }
     else	// EOS
@@ -136,7 +160,7 @@ uint64 Stream::alloc_and_read(void** data_out, uint64 size_limit)
     throw MDFN_Error(ErrnoHolder(ENOMEM));
 
    if(!(data_buffer = (uint8*)realloc(data_buffer, data_buffer_alloced)))
-    throw MDFN_Error(ErrnoHolder(errno));
+    throw MDFN_Error(ErrnoHolder(ENOMEM));
 
    read(data_buffer, data_buffer_size);
   }
@@ -227,3 +251,86 @@ int Stream::get_line(std::string &str)
  return(str.length() ? 256 : -1);
 }
 
+/*
+StreamPosFilter::StreamPosFilter(std::shared_ptr<Stream> s_) : s(s_), pos(0)
+{
+
+}
+
+uint64 StreamPosFilter::read(void *data, uint64 count, bool error_on_eos)
+{
+ if(s->tell() != pos)
+  s->seek(pos, SEEK_SET);
+
+ uint64 ret = s->read(data, count, error_on_eos);
+
+ pos += ret;
+
+ return ret; 
+}
+
+void StreamPosFilter::write(const void *data, uint64 count)
+{
+ if(s->tell() != pos)
+  s->seek(pos, SEEK_SET);
+
+ try
+ {
+  s->write(data, count);
+ }
+ catch(...)
+ {
+  try { pos = s->tell(); } catch(...) { }
+  throw;
+ }
+
+ pos += count;
+
+ return ret;
+}
+
+void StreamPosFilter::seek(int64 offset, int whence)
+{
+ try
+ {
+  s->seek(offset, whence);
+ }
+ catch(...)
+ {
+  try { pos = s->tell(); } catch(...) { }
+  throw; 
+ }
+
+ pos = s->tell();
+}
+
+uint64 StreamPosFilter::tell(void)
+{
+ return pos;
+}
+
+uint64 StreamPosFilter::size(void)
+{
+ return s->size();
+}
+
+void StreamPosFilter::close(void)
+{
+ s->close();
+}
+
+uint64 StreamPosFilter::attributes(void)
+{
+ return s->attributes();
+}
+
+void StreamPosFilter::truncate(uint64 length)
+{
+ s->trruncate(length);
+}
+
+void StreamPosFilter::flush(void)
+{
+ s->flush();
+}
+*/
