@@ -141,7 +141,7 @@ static unsigned long long ParsePhysAddr(const char *za)
  {
   unsigned int bank = 0, offset = 0;
 
-  if(!strcasecmp(CurGame->shortname, "wswan"))
+  if(!MDFN_strazicmp(CurGame->shortname, "wswan"))
   {
    trio_sscanf(za, "%04x:%04x", &bank, &offset);
    ret = ((bank << 4) + offset) & 0xFFFFF;
@@ -506,6 +506,7 @@ typedef enum
 
 // FIXME, cleanup, less spaghetti:
 static PromptType InPrompt = None;
+static SDL_Keycode PromptTAKC = SDLK_UNKNOWN;
 static const RegType* CurRegIP;
 static const RegGroupType* CurRegGroupIP;
 
@@ -614,7 +615,7 @@ class DebuggerPrompt : public HappyPrompt
 		     {
 		      TraceLog.reset(nullptr);
 
-		      MDFN_DispMessage("%s", e.what());
+		      MDFND_OutputNotice(MDFN_NOTICE_ERROR, e.what());
 		     }
 		    }
 		   }
@@ -1238,8 +1239,6 @@ static void MDFN_COLD SetActive(bool active, unsigned which_ms)
   GfxDebugger_SetActive((WhichMode == 1) && IsActive);
   memdbg->SetActive((WhichMode == 2) && IsActive);
   LogDebugger_SetActive((WhichMode == 3) && IsActive);
-
-  SDL_MDFN_ShowCursor(IsActive);
 }
 
 static const char HexLUT[16] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F' };
@@ -1416,7 +1415,7 @@ void Debugger_GT_Event(const SDL_Event *event)
 {
   if(event->type == SDL_KEYDOWN)
   {
-   if(event->key.keysym.mod & KMOD_ALT)
+   if((event->key.keysym.mod & KMOD_LALT) && !(event->key.keysym.mod & KMOD_CTRL))
    {
     switch(event->key.keysym.sym)
     {
@@ -1470,8 +1469,28 @@ void Debugger_GT_Event(const SDL_Event *event)
 
   switch(event->type)
   {
+   case SDL_TEXTINPUT:
+	if(SDL_GetModState() & KMOD_LALT)
+  	 break;
+
+	if(PromptTAKC != SDLK_UNKNOWN)
+	 break;
+
+	if(InPrompt)
+	 myprompt->InsertKBB(event->text.text);
+
+	break;
+
+   case SDL_KEYUP:
+	if(PromptTAKC == event->key.keysym.sym)
+	 PromptTAKC = SDLK_UNKNOWN;
+	break;
+
    case SDL_KEYDOWN:
-        if(event->key.keysym.mod & KMOD_ALT)
+	if(PromptTAKC == event->key.keysym.sym && event->key.repeat)
+	 PromptTAKC = SDLK_UNKNOWN;
+
+        if(event->key.keysym.mod & KMOD_LALT)
          break;
 
         if(InPrompt)
@@ -1669,17 +1688,20 @@ void Debugger_GT_Event(const SDL_Event *event)
 		 {
 		  InPrompt = IOWriteBPS;
 		  myprompt = new DebuggerPrompt("I/O Write Breakpoints", IOWriteBreakpoints);
+		  PromptTAKC = event->key.keysym.sym;
 		 }
 		 else
 		 {
                   InPrompt = WriteBPS;
 		  myprompt = new DebuggerPrompt("Write Breakpoints", WriteBreakpoints);
+		  PromptTAKC = event->key.keysym.sym;
                  }
                 }
                 else if(event->key.keysym.mod & KMOD_CTRL)
                 {
                  InPrompt = AuxWriteBPS;
                  myprompt = new DebuggerPrompt("Aux Write Breakpoints", AuxWriteBreakpoints);
+		 PromptTAKC = event->key.keysym.sym;
                 }
 		break;
 
@@ -1688,6 +1710,7 @@ void Debugger_GT_Event(const SDL_Event *event)
 		{
 		 InPrompt = OpBPS;
 		 myprompt = new DebuggerPrompt("Opcode Breakpoints", OpBreakpoints);
+		 PromptTAKC = event->key.keysym.sym;
 		}
 		break;
 	 case SDLK_r:
@@ -1697,17 +1720,20 @@ void Debugger_GT_Event(const SDL_Event *event)
 		 {
 		  InPrompt = IOReadBPS;
 		  myprompt = new DebuggerPrompt("I/O Read Breakpoints", IOReadBreakpoints);
+		  PromptTAKC = event->key.keysym.sym;
 		 }
 		 else
 		 {
 		  InPrompt = ReadBPS;
 		  myprompt = new DebuggerPrompt("Read Breakpoints", ReadBreakpoints);
+		  PromptTAKC = event->key.keysym.sym;
 		 }
 		}
                 else if(event->key.keysym.mod & KMOD_CTRL)
                 {
                  InPrompt = AuxReadBPS;
                  myprompt = new DebuggerPrompt("Aux Read Breakpoints", AuxReadBreakpoints);
+		 PromptTAKC = event->key.keysym.sym;
                 }
 		else if(InSteppingMode)
 		 NeedRun = true;
@@ -1718,14 +1744,19 @@ void Debugger_GT_Event(const SDL_Event *event)
 		{
 		 InPrompt = TraceLogPrompt;
 		 myprompt = new DebuggerPrompt("Trace Log(filename end_pc)", TraceLogSpec);
+		 PromptTAKC = event->key.keysym.sym;
 		}
+		break;
+
 	 case SDLK_i:
 	 	if(!InPrompt && CurGame->Debugger->IRQ)
 		{
 		 InPrompt = ForceInt;
 		 myprompt = new DebuggerPrompt("Force Interrupt", "");
+		 PromptTAKC = event->key.keysym.sym;
 		}
 		break;
+
 	 case SDLK_p:
 		if(!InPrompt)
 		{
@@ -1733,11 +1764,13 @@ void Debugger_GT_Event(const SDL_Event *event)
 		 {
 		  InPrompt = PokeMeHL;
 		  myprompt = new DebuggerPrompt("HL Poke(address value size)", "");
+		  PromptTAKC = event->key.keysym.sym;
 		 }
 		 else
 		 {
 		  InPrompt = PokeMe;
 		  myprompt = new DebuggerPrompt("Poke(address value size)", "");
+		  PromptTAKC = event->key.keysym.sym;
 		 }
 		}
 		break;
@@ -1784,6 +1817,7 @@ void Debugger_GT_Event(const SDL_Event *event)
 		  }
 
                   myprompt = new DebuggerPrompt(ptext, buf);
+		  PromptTAKC = event->key.keysym.sym;
 		 }
 	         break;
          }
