@@ -58,6 +58,9 @@ class MDFNFILE
 	std::unique_ptr<Stream> str;
 
 	void Open(const char *path, const FileExtensionSpecStruct *known_ext, const char *purpose = NULL);
+
+	MDFNFILE(const MDFNFILE&);
+	MDFNFILE& operator=(const MDFNFILE&);
 };
 
 class PtrLengthPair
@@ -104,6 +107,6 @@ std::unique_ptr<Stream> MDFN_AmbigGZOpenHelper(const std::string& path, std::vec
 
 void MDFN_mkdir_T(const char* path);
 int MDFN_stat(const char*, struct stat*);
-int MDFN_unlink(const char* path);
-int MDFN_rename(const char* oldpath, const char* newpath);
+void MDFN_unlink(const char* path);
+void MDFN_rename(const char* oldpath, const char* newpath);
 #endif
