@@ -235,7 +235,7 @@ static MDFN_COLD void CloseGame(void)
  }
  catch(std::exception &e)
  {
-  MDFN_PrintError("%s", e.what());
+  MDFND_OutputNotice(MDFN_NOTICE_ERROR, e.what());
  }
 
  Cleanup();
@@ -252,7 +252,7 @@ static void StateAction(StateMem *sm, const unsigned load, const bool data_only)
  SFORMAT StateRegs[] =
  {
   SFVAR(z80_runtime),
-  SFARRAY(CPUExRAM, 16384),
+  SFVAR(CPUExRAM),
   SFVAR(FlashStatusEnable),
   SFEND
  };
@@ -262,11 +262,11 @@ static void StateAction(StateMem *sm, const unsigned load, const bool data_only)
   SFVARN(pc, "PC"),
   SFVARN(sr, "SR"),
   SFVARN(f_dash, "F_DASH"),
-  SFARRAY32N(gpr, 4, "GPR"),
-  SFARRAY32N(gprBank[0], 4, "GPRB0"),
-  SFARRAY32N(gprBank[1], 4, "GPRB1"),
-  SFARRAY32N(gprBank[2], 4, "GPRB2"),
-  SFARRAY32N(gprBank[3], 4, "GPRB3"),
+  SFVARN(gpr, "GPR"),
+  SFVARN(gprBank[0], "GPRB0"),
+  SFVARN(gprBank[1], "GPRB1"),
+  SFVARN(gprBank[2], "GPRB2"),
+  SFVARN(gprBank[3], "GPRB3"),
   SFEND
  };
 
@@ -349,13 +349,13 @@ static void SetLayerEnableMask(uint64 mask)
 
 static const IDIISG IDII =
 {
- { "up", "UP ↑", 0, IDIT_BUTTON, "down" },
- { "down", "DOWN ↓", 1, IDIT_BUTTON, "up" },
- { "left", "LEFT ←", 2, IDIT_BUTTON, "right" },
- { "right", "RIGHT →", 3, IDIT_BUTTON, "left" },
- { "a", "A", 5, IDIT_BUTTON_CAN_RAPID,  NULL },
- { "b", "B", 6, IDIT_BUTTON_CAN_RAPID, NULL },
- { "option", "OPTION", 4, IDIT_BUTTON, NULL },
+ IDIIS_Button("up", "UP ↑", 0, "down"),
+ IDIIS_Button("down", "DOWN ↓", 1, "up"),
+ IDIIS_Button("left", "LEFT ←", 2, "right"),
+ IDIIS_Button("right", "RIGHT →", 3, "left"),
+ IDIIS_ButtonCR("a", "A", 5,  NULL),
+ IDIIS_ButtonCR("b", "B", 6, NULL),
+ IDIIS_Button("option", "OPTION", 4, NULL),
 };
 
 static const std::vector<InputDeviceInfoStruct> InputDeviceInfo =
