@@ -1263,7 +1263,7 @@ static void ADPCM_StateAction(StateMem *sm, const unsigned load, const bool data
 
  SFORMAT StateRegs[] =
  {
-        SFARRAY(ADPCM.RAM, 0x10000),
+        SFPTR8(ADPCM.RAM, 0x10000),
 
         SFVAR(ADPCM.bigdiv),
         SFVAR(ADPCM.Addr),
@@ -1319,8 +1319,8 @@ void PCECD_StateAction(StateMem *sm, const unsigned load, const bool data_only)
 	 SFVAR(bBRAMEnabled),
 	 SFVAR(ACKStatus),
 	 SFVAR(ClearACKDelay),
-	 SFARRAY16(RawPCMVolumeCache, 2),
-	 SFARRAY(_Port, sizeof(_Port)),
+	 SFVAR(RawPCMVolumeCache),
+	 SFVAR(_Port),
 
 	 SFVAR(Fader.Command),
 	 SFVAR(Fader.Volume),
@@ -1328,7 +1328,7 @@ void PCECD_StateAction(StateMem *sm, const unsigned load, const bool data_only)
 	 SFVAR(Fader.CountValue),
 	 SFVAR(Fader.Clocked),
 
-	 SFARRAY(&SubChannelFIFO.data[0], SubChannelFIFO.data.size()),
+	 SFPTR8(&SubChannelFIFO.data[0], SubChannelFIFO.data.size()),
 	 SFVAR(SubChannelFIFO.read_pos),
 	 SFVAR(SubChannelFIFO.write_pos),
 	 SFVAR(SubChannelFIFO.in_count),
