@@ -30,16 +30,16 @@ extern pcecd_drive_bus_t cd_bus; // Don't access this structure directly by name
 #define PCECD_Drive_kingACK_mask	0x040
 #define PCECD_Drive_kingSEL_mask	0x100
 
-#define BSY_signal ((const bool)(cd_bus.signals & PCECD_Drive_BSY_mask))
-#define ACK_signal ((const bool)(cd_bus.signals & PCECD_Drive_kingACK_mask))
-#define RST_signal ((const bool)(cd_bus.signals & PCECD_Drive_kingRST_mask))
-#define MSG_signal ((const bool)(cd_bus.signals & PCECD_Drive_MSG_mask))
-#define SEL_signal ((const bool)(cd_bus.signals & PCECD_Drive_kingSEL_mask))
-#define REQ_signal ((const bool)(cd_bus.signals & PCECD_Drive_REQ_mask))
-#define IO_signal ((const bool)(cd_bus.signals & PCECD_Drive_IO_mask))
-#define CD_signal ((const bool)(cd_bus.signals & PCECD_Drive_CD_mask))
+#define BSY_signal ((bool)(cd_bus.signals & PCECD_Drive_BSY_mask))
+#define ACK_signal ((bool)(cd_bus.signals & PCECD_Drive_kingACK_mask))
+#define RST_signal ((bool)(cd_bus.signals & PCECD_Drive_kingRST_mask))
+#define MSG_signal ((bool)(cd_bus.signals & PCECD_Drive_MSG_mask))
+#define SEL_signal ((bool)(cd_bus.signals & PCECD_Drive_kingSEL_mask))
+#define REQ_signal ((bool)(cd_bus.signals & PCECD_Drive_REQ_mask))
+#define IO_signal ((bool)(cd_bus.signals & PCECD_Drive_IO_mask))
+#define CD_signal ((bool)(cd_bus.signals & PCECD_Drive_CD_mask))
 
-#define DB_signal ((const uint8)cd_bus.DB)
+#define DB_signal ((uint8)cd_bus.DB)
 
 #define PCECD_Drive_GetDB() DB_signal
 #define PCECD_Drive_GetBSY() BSY_signal
