@@ -22,7 +22,7 @@
 #include <mednafen/mednafen.h>
 #include <mednafen/Time.h>
 #include "qtrecord.h"
-#include "compress/minilzo.h"
+#include <minilzo/minilzo.h>
 #include "video/png.h"
 
 #include <zlib.h>
@@ -1078,7 +1078,7 @@ QTRecord::~QTRecord(void)
  }
  catch(std::exception &e)
  {
-  MDFND_PrintError(e.what());
+  MDFND_OutputNotice(MDFN_NOTICE_ERROR, e.what());
  }
 
  if(resampler)
